==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Dispositivo está ocupado</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Usado por</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Enviar último vídeo</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Enviar um ou mais Vídeos selecionados</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Instale o reprodutor de vídeo</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Você encontra o Vídeo como anexo</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Selecione um ou mais arquivos</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Borda</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Mostrar em tela cheia</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>Clique com o botão direito para abrir o menu</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>Definido pelo usuário</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Dispositivo está ocupado</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Usado por</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Tela cheia</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Não gravar o cursor do mouse</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Caminho do vídeo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Player</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimizar o Vokoscreen ao iniciar a gravação</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Tempo de Gravação</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Tamanho em KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Tamanho da tela de Gravação</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Configurações de FPS</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir diretório</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Contagem Regressiva</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Reproduzir último Vídeo</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Enviar Vídeo</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Frames por segundo</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Ir</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Homepage</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Suporte</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Desenvolvedor</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doações</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Programa para gravação</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código-Fonte</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar na área de notificação</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Nova versão disponível</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec de video </translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec de audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Selecione a webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Espelhado</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Tela</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Todas as telas</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Página Web do desenvolvedor</translation>
    </message>
</context>
</TS>

==> vokoscreen_2.5.0.orig.tar.gz: vokoscreen-2.5.0/language/vokoscreen_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Dispositivo está ocupado</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Usado por</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Show Click Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Enviar último vídeo</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Enviar um ou mais Vídeos selecionados</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Instale o reprodutor de vídeo</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Você encontra o Vídeo como anexo</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Selecione um ou mais arquivos</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Borda</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Mostrar em tela cheia</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>Clique com o botão direito para abrir o menu</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>Definido pelo usuário</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Dispositivo está ocupado</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Usado por</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Tela cheia</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Não gravar o cursor do mouse</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Caminho do vídeo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Player</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimizar o Vokoscreen ao iniciar a gravação</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Tempo de Gravação</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Tamanho em KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Tamanho da tela de Gravação</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Configurações de FPS</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir diretório</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Contagem Regressiva</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Reproduzir último Vídeo</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Enviar Vídeo</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Frames por segundo</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Ir</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Homepage</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Suporte</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Desenvolvedor</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doações</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código-Fonte</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar na área de notificação</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Nova versão disponível</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec de video </translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec de audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Selecione a webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Espelhado</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Tela</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Todas as telas</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Página Web do desenvolvedor</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select recorder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lossless</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
